<?php
/**
 * understrap Theme Customizer
 *
 * @package themely framework
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function verb_lite_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
}
add_action( 'customize_register', 'verb_lite_customize_register' );

function verb_lite_theme_customize_register( $wp_customize ) {
    
    // Primary color //
    $wp_customize->add_setting(
        'verb_lite_primary_color',
        array(
            'default'     => '#0096e8',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    );
    
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize,
        'verb_lite_primary_color',
        array(
            'label'       => esc_html__( 'Primary Color', 'verb-lite' ),
            'section'     => 'colors',
            'settings'   => 'verb_lite_primary_color'
        )
    ));
    
    // Secondary color //
    $wp_customize->add_setting(
        'verb_lite_secondary_color',
        array(
            'default'     => '#37bf91',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    );
    
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize,
        'verb_lite_secondary_color',
        array(
            'label'       => esc_html__( 'Secondary Color', 'verb-lite' ),
            'section'     => 'colors',
            'settings'   => 'verb_lite_secondary_color'
        )
    ));

    // Top Bar BG Color //
    $wp_customize->add_setting('verb_lite_top_bar_color', array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
        )
    );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize, 'verb_lite_top_bar_color', array(
            'label'       => __( 'Top Bar Background Color', 'verb-lite' ),
            'section'     => 'colors',
            'settings'   => 'verb_lite_top_bar_color',
            'description'   => __('Set the background color of the top bar.', 'verb-lite'),
            'type' => 'customtext',
            'extra' => __( 'Set the background color of the top bar. ', 'verb-lite' ),
        )
    ));

    // Home Featured BG Color //
    $wp_customize->add_setting(
        'verb_lite_home_featured_color',
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
        )
    );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_home_featured_color',
        array(
            'label'       => __( 'Home Featured Background Color', 'verb-lite' ),
            'section'     => 'colors',
            'settings'   => 'verb_lite_home_featured_color',
            'description'   => __('Set the background color of the top bar.', 'verb-lite'),
            'type' => 'customtext',
            'extra' => __( 'Set the background color of the top bar. ', 'verb-lite' ),
        )
    ));

    // Footer BG Color //
    $wp_customize->add_setting(
        'verb_lite_footer_color',
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
        )
    );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_footer_color',
        array(
            'label'       => __( 'Footer Background Color', 'verb-lite' ),
            'section'     => 'colors',
            'settings'   => 'verb_lite_footer_color',
            'description'   => __('Set the background color of the footer area.', 'verb-lite'),
            'type' => 'customtext',
            'extra' => __( 'Set the background color of the footer area. ', 'verb-lite' ),
        )
    ));

    // TYPOGRAPHY SECTION //
    $wp_customize->add_section( 'verb_lite_typography_section' , 
        array(
            'title'       => __( 'Typography Settings', 'verb-lite' ),
            'priority'    => 20,
            'description' => __( 'This section controls the font settings.', 'verb-lite' ),
    ) );
    
    /* Titles Font Style*/
    $wp_customize->add_setting('verb_lite_typography_title_font', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_typography_title_font', 
        array(
            'label'    => __( 'Titles Font Style', 'verb-lite' ),
            'settings' => 'verb_lite_typography_title_font',
            'section'  => 'verb_lite_typography_section',
            'description' => __( 'Select a font style for the titles.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Select a font style for the titles. ', 'verb-lite' ),
        )
    ) );

    /* Titles Font Weight */
    $wp_customize->add_setting('verb_lite_typography_title_weight', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_typography_title_weight', 
        array(
            'label'    => __( 'Titles Font Weight', 'verb-lite' ),
            'settings' => 'verb_lite_typography_title_weight',
            'section'  => 'verb_lite_typography_section',
            'description' => __( 'Select a font weight for the titles.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Select a font weight for the titles. ', 'verb-lite' ),
        ) 
    ));

    /* Body Font Style*/
    $wp_customize->add_setting('verb_lite_typography_body_font', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_typography_body_font', 
        array(
            'label'    => __( 'Body Font Style', 'verb-lite' ),
            'settings' => 'verb_lite_typography_body_font',
            'section'  => 'verb_lite_typography_section',
            'description' => __( 'Select a font style for the body.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Select a font weight for the titles. ', 'verb-lite' ),
        )
    ) );

    /* Body Font Weight */
    $wp_customize->add_setting('verb_lite_typography_body_weight', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_typography_body_weight', 
        array(
            'label'    => __( 'Body Font Weight', 'verb-lite' ),
            'settings' => 'verb_lite_typography_body_weight',
            'section'  => 'verb_lite_typography_section',
            'description' => __( 'Select a font weight for the body.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Select a font weight for the titles. ', 'verb-lite' ),
        )
    ) );
    
    // LAYOUT SECTION //
    $wp_customize->add_section( 'verb_lite_layout_section' , 
        array(
            'title'       => __( 'Layout Settings', 'verb-lite' ),
            'priority'    => 20,
            'description' => __( 'This section controls the layout settings.', 'verb-lite' ),
    ) );

    /* Content Width */
    $wp_customize->add_setting( 'verb_lite_content_width',
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_content_width', 
        array(
            'label'     => __( 'Content Width', 'verb-lite' ),
            'section'   => 'verb_lite_layout_section',
            'settings'  => 'verb_lite_content_width',
            'description' => __( 'Enter your preferred content width in pixels or percentage. Example: 1140px or 80%. Default is 1140px.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Enter your preferred content width in pixels or percentage. Example: 1140px or 80%. Default is 1140px. ', 'verb-lite' ),
        )
    ) );

    /* Archive Posts Style*/
    $wp_customize->add_setting('verb_lite_archive_posts_style', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_archive_posts_style', 
        array(
            'label'    => __( 'Archive Posts Style', 'verb-lite' ),
            'settings' => 'verb_lite_archive_posts_style',
            'section'  => 'verb_lite_layout_section',
            'description' => __( 'Select a style for posts.', 'verb-lite' ),
            'type'     => 'select',
            'type' => 'customtext',
            'extra' => __( 'Select a style for posts. ', 'verb-lite' ),
        )
    ) );

    /* Category Posts Style*/
    $wp_customize->add_setting('verb_lite_category_posts_style', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_category_posts_style', 
        array(
            'label'    => __( 'Category Posts Style', 'verb-lite' ),
            'settings' => 'verb_lite_category_posts_style',
            'section'  => 'verb_lite_layout_section',
            'description' => __( 'Select a style for posts.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Select a style for posts. ', 'verb-lite' ),
        ) 
    ) );

    /* Footer 1 Widgets */
    $wp_customize->add_setting('verb_lite_footer1_widgets', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_footer1_widgets', 
        array(
            'label'    => __( 'Footer 1 Widgets', 'verb-lite' ),
            'settings' => 'verb_lite_footer1_widgets',
            'section'  => 'verb_lite_layout_section',
            'description' => __( 'Select the number of widgets you want to appear in Footer 1.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Select the number of widgets you want to appear in Footer 1. ', 'verb-lite' ),
        )
    ) );

    /* Footer 2 Widgets */
    $wp_customize->add_setting('verb_lite_footer2_widgets', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_footer2_widgets', 
        array(
            'label'    => __( 'Footer 2 Widgets', 'verb-lite' ),
            'settings' => 'verb_lite_footer2_widgets',
            'section'  => 'verb_lite_layout_section',
            'description' => __( 'Select the number of widgets you want to appear in Footer 2.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Select the number of widgets you want to appear in Footer 2. ', 'verb-lite' ),
        ) 
    ) );

    // HOMEPAGE SECTION //
    $wp_customize->add_section( 'verb_lite_homepage_section' , 
        array(
            'title'       => __( 'Homepage Settings', 'verb-lite' ),
            'priority'    => 20,
            'description' => __( 'This section controls the homepage settings.', 'verb-lite' ),
    ) );

    /* Featured Style*/
    $wp_customize->add_setting('verb_lite_homepage_featured_layout', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_homepage_featured_layout', 
        array(
            'label'    => __( 'Homepage Featured Layout', 'verb-lite' ),
            'settings' => 'verb_lite_homepage_featured_layout',
            'section'  => 'verb_lite_homepage_section',
            'description' => __( 'Select a style for the featured posts.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Select a style for the featured posts. ', 'verb-lite' ),
        ) 
    ) );

    /* Homepage Posts Style*/
    $wp_customize->add_setting('verb_lite_homepage_posts_style', 
        array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_homepage_posts_style', 
        array(
            'label'    => __( 'Homepage Posts Style', 'verb-lite' ),
            'settings' => 'verb_lite_homepage_posts_style',
            'section'  => 'verb_lite_homepage_section',
            'description' => __( 'Select a style for posts.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Select a style for posts. ', 'verb-lite' ),
        ) 
    ) );

    $wp_customize->add_setting('verb_lite_homepage_featured_posts', 
        array(
            'default'        => 'uncategorized',
            'capability'     => 'edit_theme_options',
            'sanitize_callback' => 'verb_lite_sanitize_text'
    ) );
    
    $wp_customize->add_control( 'verb_lite_homepage_featured_posts', 
        array(
            'settings' => 'verb_lite_homepage_featured_posts',
            'label'    => __( 'Featured Posts Category', 'verb-lite' ),
            'description' => __( 'Select a category to populate the featured posts. If you have not done so already, create a post category entitled Featured, and assign posts to that category. Then select it from this dropdown.', 'verb-lite' ),
            'section'  => 'verb_lite_homepage_section',
            'type'     => 'select',
            'choices'  => get_categories_select()
    ) );

    $wp_customize->add_setting( 'verb_lite_featured_toggle', array( 
        'sanitize_callback' => 'esc_attr',
    ) );

    $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
        'verb_lite_featured_toggle',
        array(
            'label'     => __( 'Featured Posts Section', 'verb-lite' ),
            'description' => __( 'Click to enable the featured posts section.', 'verb-lite' ),
            'section'   => 'verb_lite_homepage_section',
            'settings'  => 'verb_lite_featured_toggle',
            'type'      => 'checkbox',
        )
    ) );
    
    // TOP HEADER SOCIAL SECTION //

    $wp_customize->add_section( 'verb_lite_topbar_section' , 
        array(
            'title'       => __( 'Top Bar Settings', 'verb-lite' ),
            'priority'    => 20,
            'description' => __( 'This section controls the top bar which appears at the very top of the theme.', 'verb-lite' ),
    ) );

    $wp_customize->add_setting( 'verb_lite_topbar_toggle', 
        array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );

    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_topbar_toggle',
        array(
            'label'     => __( 'Toggle Top Bar', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the top bar.', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'settings'  => 'verb_lite_topbar_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the top bar. ', 'verb-lite' ),
        )
    ) );

    $wp_customize->add_setting( 'verb_lite_topbar_date_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );

    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_topbar_date_toggle',
        array(
            'label'     => __( 'Toggle Date', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the date displayed in the top bar.', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'settings'  => 'verb_lite_topbar_date_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the date displayed in the top bar. ', 'verb-lite' ),
        )
    ) );
    
    $wp_customize->add_setting( 'verb_lite_social_facebook',
        array(
            'default'     => '',
            'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control(
        'verb_lite_social_facebook', 
        array(
            'label'     => __( 'Facebook Profile URL', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'type'      => 'text',
            'settings'  => 'verb_lite_social_facebook',
            'description' => __( 'Enter the link to your Facebook profile page.', 'verb-lite' ),
    ));
    
    $wp_customize->add_setting( 'verb_lite_social_twitter',
        array(
            'default'     => '',
            'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control(
        'verb_lite_social_twitter', 
        array(
            'label'     => __( 'Twitter Profile URL', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'type'      => 'text',
            'settings'  => 'verb_lite_social_twitter',
            'description' => __( 'Enter the link to your Twitter profile page.', 'verb-lite' ),
    ));
    
    $wp_customize->add_setting( 'verb_lite_social_linkedin',
        array(
            'default'     => '',
            'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control(
        'verb_lite_social_linkedin', 
        array(
            'label'     => __( 'Linkedin Profile URL', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'type'      => 'text',
            'settings'  => 'verb_lite_social_linkedin',
            'description' => __( 'Enter the link to your Linkedin profile page.', 'verb-lite' ),
    ));
    
    $wp_customize->add_setting( 'verb_lite_social_pinterest',
        array(
            'default'     => '',
            'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control(
        'verb_lite_social_pinterest', 
        array(
            'label'     => __( 'Pinterest Profile URL', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'type'      => 'text',
            'settings'  => 'verb_lite_social_pinterest',
            'description' => __( 'Enter the link to your Pinterest profile page.', 'verb-lite' ),
    ));
    
    $wp_customize->add_setting( 'verb_lite_social_google',
        array(
            'default'     => '',
            'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control(
        'verb_lite_social_google', 
        array(
            'label'     => __( 'Google Plus Profile URL', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'type'      => 'text',
            'settings'  => 'verb_lite_social_google',
            'description' => __( 'Enter the link to your Google Plus profile page.', 'verb-lite' ),
    ));
    
    $wp_customize->add_setting( 'verb_lite_social_instagram',
        array(
            'default'     => '',
            'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control(
        'verb_lite_social_instagram', 
        array(
            'label'     => __( 'Instagram Profile URL', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'type'      => 'text',
            'settings'  => 'verb_lite_social_instagram',
            'description' => __( 'Enter the link to your Instagram profile page.', 'verb-lite' ),
    ));
    
    $wp_customize->add_setting( 'verb_lite_social_youtube',
        array(
            'default'     => '',
            'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control(
        'verb_lite_social_youtube', 
        array(
            'label'     => __( 'Youtube Profile URL', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'type'      => 'text',
            'settings'  => 'verb_lite_social_youtube',
            'description' => __( 'Enter the link to your Youtube profile page.', 'verb-lite' ),
    ));
    
    $wp_customize->add_setting( 'verb_lite_social_tumblr',
        array(
            'default'     => '',
            'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control(
        'verb_lite_social_tumblr', 
        array(
            'label'     => __( 'Tumblr Profile URL', 'verb-lite' ),
            'section'   => 'verb_lite_topbar_section',
            'type'      => 'text',
            'settings'  => 'verb_lite_social_tumblr',
            'description' => __( 'Enter the link to your Tumblr profile page.', 'verb-lite' ),
    ));

    // BLOG/POST SETTINGS //
    $wp_customize->add_section( 'verb_lite_blog_section' , 
        array(
            'title'       => __( 'Blog/Post Settings', 'verb-lite' ),
            'priority'    => 20,
            'description' => __( 'This section controls the various settings related to the blog and  posts.', 'verb-lite' ),
    ) );

    /* Scroll Reveal Toggle */
    $wp_customize->add_setting( 'verb_lite_blog_scrollreveal_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );

    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_blog_scrollreveal_toggle',
        array(
            'label'     => __( 'Toggle Scroll Reveal', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the Scroll Reveal animation.', 'verb-lite' ),
            'section'   => 'verb_lite_blog_section',
            'settings'  => 'verb_lite_blog_scrollreveal_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the Scroll Reveal animation. ', 'verb-lite' ),
        )
    ) );

    /* Post Meta Toggle */
    $wp_customize->add_setting( 'verb_lite_blog_meta_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );

    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_blog_meta_toggle',
        array(
            'label'     => __( 'Toggle Post Meta', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the post meta (Author, Date, Comments Count & Category).', 'verb-lite' ),
            'section'   => 'verb_lite_blog_section',
            'settings'  => 'verb_lite_blog_meta_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the post meta (Author, Date, Comments Count & Category). ', 'verb-lite' ),
        )
    ) );

    /* Read More Toggle */
    $wp_customize->add_setting( 'verb_lite_blog_readmore_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );

    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_blog_readmore_toggle',
        array(
            'label'     => __( 'Toggle Read More', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the Read More button.', 'verb-lite' ),
            'section'   => 'verb_lite_blog_section',
            'settings'  => 'verb_lite_blog_readmore_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the Read More button. ', 'verb-lite' ),
        )
    ) );

    /* Featured Image Toggle */
    $wp_customize->add_setting( 'verb_lite_blog_featured_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );

    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_blog_featured_toggle',
        array(
            'label'     => __( 'Toggle Featured Image', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the featured image on single posts.', 'verb-lite' ),
            'section'   => 'verb_lite_blog_section',
            'settings'  => 'verb_lite_blog_featured_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the featured image on single posts. ', 'verb-lite' ),
        )
    ) );
    
    /* Social Toggle */
    $wp_customize->add_setting( 'verb_lite_blog_social_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_blog_social_toggle',
        array(
            'label'     => __( 'Toggle Social Sharing', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the social sharing icons which appear at the bottom of posts.', 'verb-lite' ),
            'section'   => 'verb_lite_blog_section',
            'settings'  => 'verb_lite_blog_social_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the social sharing icons which appear at the bottom of posts. ', 'verb-lite' ),
        )
    ) );

    /* Author Toggle */
    $wp_customize->add_setting( 'verb_lite_blog_author_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_blog_author_toggle',
        array(
            'label'     => __( 'Toggle Author Profile', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the author profile which appear at the bottom of posts.', 'verb-lite' ),
            'section'   => 'verb_lite_blog_section',
            'settings'  => 'verb_lite_blog_author_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the author profile which appear at the bottom of posts. ', 'verb-lite' ),
        )
    ) );

    /* Related Posts Toggle */
    $wp_customize->add_setting( 'verb_lite_blog_related_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_blog_related_toggle',
        array(
            'label'     => __( 'Toggle Related Posts', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the related posts which appear at the bottom of single posts.', 'verb-lite' ),
            'section'   => 'verb_lite_blog_section',
            'settings'  => 'verb_lite_blog_related_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the related posts which appear at the bottom of single posts. ', 'verb-lite' ),
        )
    ) );

    /* Post Naviagtion Toggle */
    $wp_customize->add_setting( 'verb_lite_blog_navigation_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_blog_navigation_toggle',
        array(
            'label'     => __( 'Toggle Posts Navigation', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the posts naviagtion which appear at the bottom of single posts.', 'verb-lite' ),
            'section'   => 'verb_lite_blog_section',
            'settings'  => 'verb_lite_blog_navigation_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the posts naviagtion which appear at the bottom of single posts. ', 'verb-lite' ),
        )
    ) );

    /* Comments Toggle */
    $wp_customize->add_setting( 'verb_lite_blog_comments_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_blog_comments_toggle',
        array(
            'label'     => __( 'Toggle Comments', 'verb-lite' ),
            'description' => __( 'Click to enable/disable comments on posts.', 'verb-lite' ),
            'section'   => 'verb_lite_blog_section',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable comments on posts. ', 'verb-lite' ),
        )
    ) );
    
    // FOOTER SECTION //
    $wp_customize->add_section( 'verb_lite_footer_section' , 
        array(
            'title'       => __( 'Footer Settings', 'verb-lite' ),
            'priority'    => 20,
    ) );

    // Footer Scroll to Top //
    $wp_customize->add_setting( 'verb_lite_scrolltotop_toggle', array( 
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );

    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_scrolltotop_toggle',
        array(
            'label'     => __( 'Toggle Scroll-to-Top', 'verb-lite' ),
            'description' => __( 'Click to enable/disable the scroll-to-top link which appears in the bottom right hand corner of the screen and in the footer.', 'verb-lite' ),
            'section'   => 'verb_lite_footer_section',
            'settings'  => 'verb_lite_scrolltotop_toggle',
            'type' => 'customtext',
            'extra' => __( 'Click to enable/disable the scroll to top link which appears in the bottom right hand corner of the screen and in the footer. ', 'verb-lite' ),
        )
    ) );
    
    // Footer Copyright //
    $wp_customize->add_setting( 'verb_lite_footer_copyright', array(
            'default'           => '',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_html',
    ) );
    
    $wp_customize->add_control( new Verb_Lite_Custom_Text_Control( $wp_customize,
        'verb_lite_footer_copyright', 
        array(
            'label'     => __( 'Copyright Text', 'verb-lite' ),
            'section'   => 'verb_lite_footer_section',
            'settings'  => 'verb_lite_footer_copyright',
            'description' => __( 'Change the copyright text which appears at the bottom of the footer.', 'verb-lite' ),
            'type' => 'customtext',
            'extra' => __( 'Change the copyright text which appears at the bottom of the footer. ', 'verb-lite' ),
        )
    ) );
    
    // Sanitize text
	function verb_lite_sanitize_text( $text ) {
	    return sanitize_text_field( $text );
	}

}
add_action( 'customize_register', 'verb_lite_theme_customize_register' );

/**
 * Get list of categories
 */
function get_categories_select() {
  $teh_cats = get_categories();
  $results;
 
  $count = count($teh_cats);
  for ($i=0; $i < $count; $i++) {
    if (isset($teh_cats[$i]))
      $results[$teh_cats[$i]->slug] = $teh_cats[$i]->name;
    else
      $count++;
  }
  return $results;
}

/**
 * Output the styles from the customizer
 */
function verb_lite_customizer_css() {
    ?>
    <style type="text/css">
        a:hover, a:focus {color:<?php echo esc_attr( get_theme_mod( 'verb_lite_primary_color' ) ); ?>;}
        .navbar-header .nav li:hover a, .navbar-header .nav .active a {border-bottom-color:<?php echo esc_attr( get_theme_mod( 'verb_lite_primary_color' ) ); ?>;}
        .widget-area .widget .widget-title {border-left-color: <?php echo esc_attr( get_theme_mod( 'verb_lite_primary_color' ) ); ?>;}
        .btn-primary.focus, .btn-primary:focus, .btn-primary:hover, .btn-primary, .post .cat-links a {background-color: <?php echo esc_attr( get_theme_mod( 'verb_lite_secondary_color' ) ); ?>;}
        .btn-primary.focus, .btn-primary:focus, .btn-primary:hover, .btn-primary {border-color: <?php echo esc_attr( get_theme_mod( 'verb_lite_secondary_color' ) ); ?>;}
        #wrapper-footer-full a:hover {color: <?php echo esc_attr( get_theme_mod( 'verb_lite_secondary_color' ) ); ?>;}
        #wrapper-footer aside .widget-title {border-bottom-color: <?php echo esc_attr( get_theme_mod( 'verb_lite_secondary_color' ) ); ?>;}
    </style>
    <?php
}
add_action( 'wp_head', 'verb_lite_customizer_css' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function verb_lite_customize_preview_js() {
	wp_enqueue_script( 'verb_lite_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'verb_lite_customize_preview_js' );
